@@ -94,15 +94,21 @@ int main(int argc, char** argv)
     hp_print_externals(crawl, params.where_start);
   } else {
     int i;
+    uri_t* url_object = uri_alloc("http://fake.net/", 16);
     for(i = optind; i < argc; i++) {
+      char* url;
+      if(uri_realloc(url_object, argv[i], strlen(argv[i])) != URI_CANNONICAL) {
+	fprintf(stderr, "crawler: cannnot cannonicalize %s, ignored\n", argv[i]);
+      }
+      url = uri_uri(url_object);
       if(params.remove_unloaded)
-	hp_remove_unloaded(crawl, argv[i]);
+	hp_remove_unloaded(crawl, url);
       if(params.touch)
-	crawl_touch(crawl, argv[i]);
+	crawl_touch(crawl, url);
       else if(params.unload)
-	hp_unload(crawl, argv[i], params.unload_keep_start);
+	hp_unload(crawl, url, params.unload_keep_start);
       else
-	hp_load_in_core(crawl, argv[i]);
+	hp_load_in_core(crawl, url);
     }
   }
   finish();
