@@ -19,10 +19,6 @@
 #ifndef _crawl_private_h
 #define _crawl_private_h
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 struct crawl_params;
 
 #include <webbase.h>
@@ -54,13 +50,9 @@ typedef struct crawl_context {
 #define CRAWL_MAX_TIMEOUTS	5
 #define CRAWL_MAX_REDIRECTIONS	10
 
-#define CRAWL_USER_AGENT "ecila/4.0"
+#define CRAWL_USER_AGENT "webbase/5.11"
 
 int mirror_collect(char* contextp, webbase_url_t* base_url, char* url, int flag);
 webbase_url_t* mirror(crawl_context_t* context, char* url);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* _crawl_private_h */
