@@ -15,6 +15,14 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
  *
+ * Store and use URL selection patterns (from robots.txt files or
+ * user specified). The crawler will make use of those functions to
+ * find out if a URL is elligible for crawling or not. It is also
+ * a convinience library of the robot exclusion protocol module.
+ *
+ */
+/*
+ * Match a URL against Allow and Disallow robots.txt clauses
  */
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -40,18 +48,39 @@
 #include <uri.h>
 #include <salloc.h>
 
+/*
+ * Search for match at beginning of string (anchored)
+ */
 #define DIRSEL_BOL	'/'
+/*
+ * Search for match anywhere in string
+ */
 #define DIRSEL_ANY	'A'
 
+/*
+ * List of strings (allowed or disallowed). 
+ * The prefix variable is a list of string.
+ * The prefix_length variable is the number of strings in prefix.
+ * 
+ */
 typedef struct dirsel {
   int info;
+
+  /* List of strings to find in the URL */
   char** prefix;
-  int prefix_size;
+  /* Length of the list */
   int prefix_length;
+
+  int prefix_size;
   char* pool;
   int pool_size;
 } dirsel_t;
 
+/*
+ * Instance object. Holds mapping between server names
+ * and struct dirsel entries listing the allowed/disallowed strings.
+ * The url_object member is only here for performance reasons.
+ */
 typedef struct context {
   hash_t* allow;
   hash_t* disallow;
@@ -83,10 +112,13 @@ static void hnode_free(hnode_t *node, void *)
   free(node);
 }
 
+/*
+ * Create a table for robots.txt Allow/Disallow attributes + user provided Allow/Disallow
+ */
 void dirsel_init()
 {
   if(context.url_object == 0) {
-    int size = 257;
+    int size = HASHCOUNT_T_MAX;
     context.allow = hash_create(size, 0, 0);
     hash_set_allocator(context.allow, 0, hnode_free, 0);
     context.disallow = hash_create(size, 0, 0);
@@ -120,6 +152,9 @@ static void dirsel_end_1(hash_t* table)
   hash_free(table);
 }
 
+/*
+ * Add a list of strings <dirs> to the user specified Allow clauses
+ */
 void dirsel_allow(char* url, char* dirs, int flag)
 {
   char* netpath;
@@ -129,6 +164,9 @@ void dirsel_allow(char* url, char* dirs, int flag)
   dirsel_insert(context.allow, netpath, dirs, flag);
 }
 
+/*
+ * Add a list of strings <dirs> to the user specified Disallow clauses
+ */
 void dirsel_disallow(char* url, char* dirs, int flag)
 {
   char* netpath;
@@ -138,18 +176,27 @@ void dirsel_disallow(char* url, char* dirs, int flag)
   dirsel_insert(context.disallow, netpath, dirs, flag);
 }
 
+/*
+ * Add a list of strings <dirs> to the robots.txt Allow clauses
+ */
 void dirsel_robots_allow(char* netloc, char* dirs, int flag)
 {
   if(verbose) fprintf(stderr, "\tdirsel_robots_allow: %s (%s)\n", netloc, dirs);
   dirsel_insert(context.robots_allow, netloc, dirs, flag);
 }
 
+/*
+ * Add a list of strings <dirs> to the robots.txt Disallow clauses
+ */
 void dirsel_robots_disallow(char* netloc, char* dirs, int flag)
 {
   if(verbose) fprintf(stderr, "\tdirsel_robots_disallow: %s (%s)\n", netloc, dirs);
   dirsel_insert(context.robots_disallow, netloc, dirs, flag);
 }
 
+/*
+ * Backend of dirsel_*allow: split <dirs> and feed the structure
+ */
 static void dirsel_insert(hash_t* table, char* key, char* dirs, int flag)
 {
   hnode_t* node = hash_lookup(table, key);
@@ -177,7 +224,8 @@ static void dirsel_insert(hash_t* table, char* key, char* dirs, int flag)
 
 /*
  * Return true if url_object is allowed considering
- * the restrictions associated to netpath.
+ * the restrictions associated to netpath. Priority goes to robots.txt specification
+ * then to user specified specifications.
  */
 int dirsel_allowed(char* netpath, char* url)
 {
@@ -219,6 +267,10 @@ int dirsel_allowed(char* netpath, char* url)
   }
 }
 
+/*
+ * Return true if comparable is allowed according to allow/disallow specifications.
+ * First allow is considered, then disallow.
+ */
 static int dirsel_allowed_1(char* comparable, dirsel_t* allow, dirsel_t* disallow)
 {
   /*
@@ -248,6 +300,10 @@ static int dirsel_allowed_1(char* comparable, dirsel_t* allow, dirsel_t* disallo
   }
 }
 
+/*
+ * Return netpath URL part into a string fit to compare with strings stored
+ * in dirsel_t structures.
+ */
 static char* dirsel_comparable(char* netpath, uri_t* url_object)
 {
   char* fake_netpath = dirsel_netpath(url_object);
@@ -310,6 +366,9 @@ static dirsel_t* dirsel_alloc()
   return entry;
 }
 
+/*
+ * Return netpath component from <url>
+ */
 char* dirsel_key(char* url)
 {
   if(verbose) fprintf(stderr, "\tdirsel_key: %s\n", url);
@@ -324,6 +383,9 @@ char* dirsel_key(char* url)
     return "_unlikely_";
 }
 
+/*
+ * Return netpath component from <url_object>
+ */
 static char* dirsel_netpath(uri_t* url_object)
 {
   static char* netpath = 0;
