@@ -19,14 +19,11 @@
 #ifndef _robots_parser_h
 #define _robots_parser_h
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
+/*
+ * Parse the content of a robots.txt file in file <path>
+ * and return the list of Allow strings in <allowp> and the 
+ * list of Disallow strings in <disallowp>.
+ */
 int robots_parse(char* path, char** allowp, char** disallowp);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* _robots_parser_h */
