@@ -54,12 +54,19 @@ typedef struct webtools_params {
   /* Common */
   hash_t* options;
 
+  /* 1.0 or 1.1 */
   char* http_level;
-  webtools_reader_callback_t callback1;
-  webtools_reader_callback_t callback2;
+  /* Call when reading form header */
+  webtools_reader_callback_t callback_http_header;
+  /* Call when reading from body */
+  webtools_reader_callback_t callback_http_body;
+  /* User defined data */
   char* callback_arg;
+  /* Open mode O_RDWR O_RDONLY */
   int mode;
+  /* Timeout for connection and IO in seconds */
   int timeout;
+  /* Maximum total size of bytes read from input */
   int size_limit;
   webtools_file_t files[WEBTOOLS_MAX_FD];
 } webtools_params_t;
@@ -67,9 +74,21 @@ typedef struct webtools_params {
 webtools_params_t* webtools_alloc(int argc, char** argv, struct option options[]);
 struct option* webtools_options(struct option options[]);
 void webtools_free(webtools_params_t* params);
+/*
+ * Open connection to <host>:<port> 
+ */
 int webtools_open(webtools_params_t* params, char* host, char* port);
+/*
+ * Write <buffer> of <size> bytes to file descriptor <sd>
+ */
 int webtools_write(webtools_params_t* params, int sd, char* buffer, int size);
+/*
+ * Close connection
+ */
 void webtools_close(webtools_params_t* params, int sd);
+/*
+ * Read from <sd> invoking params.callbacks when data is available
+ */
 int webtools_reader(webtools_params_t* params, int sd);
 
 #endif /* _webtools_h */
