@@ -300,7 +300,7 @@ int WebbaseHookMifluz::InsertContent(const char* buffer, int buffer_length)
       key.Set(POS_Location,key[POS_Location]+1);
       key.SetWord(String((char*)word_start, p - word_start));
       if(verbose) fprintf(stderr, "WebbaseHookMifluz::InsertContent: %s\n", (char*)wordRef->Get());
-      inv->Insert(*wordRef);
+      inv->Override(*wordRef);
     }
     word_start = p;
   }
