@@ -19,6 +19,14 @@
 #ifndef _strdup_h
 #define _strdup_h
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 char *strdup (const char *str);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* strdup_h */
